@@ -21,7 +21,12 @@
 #ifndef CONFIGWIDGET_H
 #define CONFIGWIDGET_H
 
+#include "ui_appearanceSettings.h"
+#include "ui_comicSettings.h"
+
 #include <QtGui/QWidget>
+#include <QTime>
+
 #include <Plasma/DataEngine>
 
 class ComicModel;
@@ -37,8 +42,8 @@ class ConfigWidget : public QWidget
         ConfigWidget( Plasma::DataEngine *engine, QWidget *parent );
         ~ConfigWidget();
 
-        void setComicIdentifier( const QString &comic );
-        QString comicIdentifier() const;
+        void setComicIdentifier( const QStringList &comics );
+        QStringList comicIdentifier() const;
 
         void setShowComicUrl( bool show );
         bool showComicUrl() const;
@@ -50,18 +55,31 @@ class ConfigWidget : public QWidget
         bool showComicIdentifier() const;
         void setArrowsOnHover( bool arrows );
         bool arrowsOnHover() const;
+        void setMiddleClick( bool checked );
+        bool middleClick() const;
+        void setTabSwitchTime( const QTime &time );
+        QTime tabSwitchTime() const;
+        void setHideTabBar( bool hide );
+        bool hideTabBar() const;
+        void setUseTabs( bool use );
+        bool useTabs() const;
+        void setSwitchTabs( bool switchTabs );
+        bool switchTabs() const;
+        QStringList comicName() const;
+
+        QWidget *comicSettings;
+        QWidget *appearanceSettings;
+
+    Q_SIGNALS:
+        void maxSizeClicked();
+
 
     protected slots:
         void getNewStuff();
 
     private:
-        QComboBox *mComicIdentifier;
-        QCheckBox *mShowComicUrl;
-        QCheckBox *mShowComicAuthor;
-        QCheckBox *mShowComicTitle;
-        QCheckBox *mShowComicIdentifier;
-        QCheckBox *mShowArrowsOnHover;
-        QPushButton *mNewStuff;
+        Ui::ComicSettings comicUi;
+        Ui::AppearanceSettings appearanceUi;
         ComicModel *mModel;
         Plasma::DataEngine *mEngine;
         QSortFilterProxyModel *mProxyModel;
