@@ -21,51 +21,53 @@
 
 #include "fuzzyClock.h"
 
-#include <math.h>
-
-#include <QPainter>
-#include <QStyleOptionGraphicsItem>
 #include <QFontMetrics>
-#include <KGlobalSettings>
-#include <QtGui/QGraphicsView>
-#include <QtGui/QGraphicsSceneMouseEvent>
+#include <QPainter>
+#include <QFontInfo>
 
-#include <KDebug>
-#include <KLocale>
-#include <KSharedConfig>
+#include <KColorScheme>
 #include <KConfigDialog>
+#include <KDebug>
 
-#include <KSystemTimeZones>
-
-
+#include <Plasma/Theme>
 
 Clock::Clock(QObject *parent, const QVariantList &args)
-    : Plasma::Applet(parent, args),
+    : ClockApplet(parent, args),
       m_oldContentSize(QSizeF (0,0)),
       m_adjustToHeight(1),
+      m_useCustomFontColor(false),
       m_fontColor(Qt::white),
       m_fontTimeBold(false),
+      m_fontTimeItalic(false),
       m_fontTime(KGlobalSettings::smallestReadableFont()),
       m_showTimezone(false),
       m_showDate(false),
       m_showYear(false),
       m_showDay(false),
-      m_calendar(0),
       m_layout(0)
 {
+    KGlobal::locale()->insertCatalog("libplasmaclock");
+    KGlobal::locale()->insertCatalog("timezones4");
     setHasConfigurationInterface(true);
     setBackgroundHints(Plasma::Applet::DefaultBackground);
     //If we do not set this, the user has to press CTRL when shrinking the plasmoid on the desktop beyond a certain size.
     setAspectRatioMode(Plasma::IgnoreAspectRatio);
 }
 
+Clock::~Clock()
+{
+}
+
 void Clock::init()
 {
+    ClockApplet::init();
+
+    initFuzzyTimeStrings();
+
     m_contentSize = geometry().size();
 
     kDebug() << "The first content's size [geometry().size()] we get, init() called: " << geometry().size();
 
-    m_localTimezone = KSystemTimeZones::local();
     m_locale = KGlobal::locale();
 
     KConfigGroup cg = config();
@@ -75,16 +77,20 @@ void Clock::init()
     m_showYear = cg.readEntry("showYear",false);
     m_showDay = cg.readEntry("showDay",true);
 
-    m_useLocalTimezone = cg.readEntry("useLocalTimezone",true);
-    m_timezone = KSystemTimeZones::zone ( cg.readEntry("timezone", m_localTimezone.name() ));
-
     m_fuzzyness = cg.readEntry("fuzzyness", 1);
 
     m_fontTime = cg.readEntry("fontTime", KGlobalSettings::smallestReadableFont());
-    m_fontColor = cg.readEntry("fontColor", m_fontColor);
+    m_useCustomFontColor = cg.readEntry("useCustomFontColor", false);
+    if (m_useCustomFontColor){
+        m_fontColor = cg.readEntry("fontColor", m_fontColor);
+    }else{
+        m_fontColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
+    }
     m_fontTimeBold = cg.readEntry("fontTimeBold", true);
+    m_fontTimeItalic = cg.readEntry("fontTimeItalic", false);
 
     m_fontTime.setBold(m_fontTimeBold);
+    m_fontTime.setItalic(m_fontTimeItalic);
 
     m_adjustToHeight = cg.readEntry("adjustToHeight", 1);
 
@@ -94,12 +100,10 @@ void Clock::init()
     m_margin = 2;
     m_verticalSpacing = 2;
 
-    if( m_timezone.name().isEmpty() ) {
-        m_timezone = m_localTimezone;
-    }
-
     Plasma::DataEngine* timeEngine = dataEngine("time");
-    timeEngine->connectSource(m_timezone.name(), this, 6000, Plasma::AlignToMinute);
+    timeEngine->connectSource(currentTimezone(), this, 6000, Plasma::AlignToMinute);
+
+    connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(updateColors()));
 }
 
 Qt::Orientations Clock::expandingDirections() const
@@ -117,16 +121,14 @@ void Clock::constraintsEvent(Plasma::Constraints constraints)
 {
     kDebug() << "constraintsEvent() called";
 
-    if ( (m_oldContentSize.toSize() != geometry().size() && m_oldContentSize.toSize() != QSize (0,0)) || m_configUpdated == true ) { //The size changed or config was updated
-        kDebug() << "The content's size [geometry().size()] changed! old: " << m_oldContentSize << "new: " << geometry().size();
+    if (constraints & Plasma::SizeConstraint || constraints & Plasma::FormFactorConstraint) {
+        if ( (m_oldContentSize.toSize() != geometry().size() && m_oldContentSize.toSize() != QSize (0,0)) || m_configUpdated == true ) { //The size changed or config was updated
+            kDebug() << "The content's size [geometry().size()] changed! old: " << m_oldContentSize << "new: " << geometry().size();
 
-        if ( m_configUpdated ) {
-            calculateDateString();
-            calculateTimeString();
-        }
-
-        //Contraints have changed, e.g. size.
-        if (constraints & Plasma::SizeConstraint) {
+            if ( m_configUpdated ) {
+                calculateDateString();
+                calculateTimeString();
+            }
 
             kDebug() << "Constraints changed: " << constraints;
 
@@ -140,12 +142,12 @@ void Clock::constraintsEvent(Plasma::Constraints constraints)
                 calculateSize();
             }
 
-        kDebug() << "The new size has been calculated and set.\nneeded m_contenSize (if not in panel): " << m_contentSize << "\nactual content's size [geometry().size()] is: " << geometry().size() << "\nminimumSize() needed (in panel): " << minimumSize();
+            kDebug() << "The new size has been calculated and set.\nneeded m_contenSize (if not in panel): " << m_contentSize << "\nactual content's size [geometry().size()] is: " << geometry().size() << "\nminimumSize() needed (in panel): " << minimumSize();
 
-        m_oldContentSize = geometry().size();
-        m_configUpdated = false;
+            m_oldContentSize = geometry().size();
+            m_configUpdated = false;
 
-        update();
+            update();
         }
     }
 }
@@ -164,13 +166,17 @@ void Clock::dataUpdated(const QString& source, const Plasma::DataEngine::Data &d
         return;
     }
 
+    if (Plasma::ToolTipManager::self()->isVisible(this)) {
+        updateTipContent();
+    }
+
     m_lastTimeSeen = m_time;
 
     calculateDateString();
     calculateTimeString();
 
     //The timestring changed.
-    if( m_timeString != m_lastTimeStringSeen || m_dateString != m_lastDateStringSeen ) {
+    if (m_timeString != m_lastTimeStringSeen || m_dateString != m_lastDateStringSeen) {
 
         //The size might have changed
         calculateSize();
@@ -185,53 +191,11 @@ void Clock::dataUpdated(const QString& source, const Plasma::DataEngine::Data &d
     }
 }
 
-void Clock::mousePressEvent(QGraphicsSceneMouseEvent *event)
-{
-    if (event->buttons() == Qt::LeftButton && rect().contains(event->pos())) {
-        showCalendar(event);
-    } else {
-        event->ignore();
-    }
-}
-
-void Clock::showCalendar(QGraphicsSceneMouseEvent *event)
-{
-    if (m_calendar == 0) {
-        m_calendar = new Plasma::Dialog();
-        //m_calendar->setStyleSheet("{ border : 0px }"); // FIXME: crashes
-        m_layout = new QVBoxLayout();
-        m_layout->setSpacing(0);
-        m_layout->setMargin(0);
-
-        m_calendarUi.setupUi(m_calendar);
-        m_calendar->setLayout(m_layout);
-        m_calendar->setWindowFlags(Qt::Popup);
-        m_calendar->adjustSize();
-    }
-
-    if (m_calendar->isVisible()) {
-        m_calendar->hide();
-    } else {
-        m_calendar->position(event, boundingRect(), mapToScene(boundingRect().topLeft()));
-        m_calendar->show();
-    }
-}
-
-void Clock::createConfigurationInterface(KConfigDialog *parent)
+void Clock::createClockConfigurationInterface(KConfigDialog *parent)
 {
     QWidget *widget = new QWidget();
     ui.setupUi(widget);
-    parent->setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
-    connect(parent, SIGNAL(applyClicked()), this, SLOT(configAccepted()));
-    connect(parent, SIGNAL(okClicked()), this, SLOT(configAccepted()));
-    parent->addPage(widget, parent->windowTitle(), icon());
-
-    ui.useLocalTimeZone->setChecked( m_useLocalTimezone );
-    //FIXME: There are several bugs in KTimeZones. 1. Even though the correct zone is selected debug-output states "no such zon: 'nameofZone'"
-    //2. If one opens the settings the first time setSelected does not work. It only does the second time settings are opened.
-    //3. If the sorting is set to true the widget does not return any values.
-    ui.timeZones->setSelected( m_timezone.name(), true );
-    ui.timeZones->setEnabled( !m_useLocalTimezone );
+    parent->addPage(widget, i18n("General"), icon());
 
     ui.fuzzynessSlider->setSliderPosition( m_fuzzyness );
     ui.showTimezone->setChecked( m_showTimezone );
@@ -241,18 +205,16 @@ void Clock::createConfigurationInterface(KConfigDialog *parent)
     ui.adjustToHeight->setSliderPosition( m_adjustToHeight );
 
     ui.fontTimeBold->setChecked(m_fontTimeBold);
+    ui.fontTimeItalic->setChecked(m_fontTimeItalic);
     ui.fontTime->setCurrentFont(m_fontTime);
     ui.fontColor->setColor(m_fontColor);
-
-     //Set focus to this widget, oxygen's colour for selected items in a non-focused widgets are not readable.
-    ui.timeZones->setFocus( Qt::OtherFocusReason );
+    ui.useCustomFontColor->setChecked(m_useCustomFontColor);
 }
 
-void Clock::configAccepted()
+void Clock::clockConfigAccepted()
 {
     KConfigGroup cg = config();
     QGraphicsItem::update();
-    QStringList tzs = ui.timeZones->selection();
 
     m_fontTime = ui.fontTime->currentFont();
     cg.writeEntry("fontTime", m_fontTime);
@@ -260,48 +222,27 @@ void Clock::configAccepted()
     //In case adjustToHeight was disabled we have to reset the point-size of fontTime
     m_fontTime.setPointSize ( m_fontDate.pointSize() );
 
-    m_fontColor = ui.fontColor->color();
-    cg.writeEntry("fontColor", m_fontColor);
+    m_useCustomFontColor = ui.useCustomFontColor->isChecked();
+    cg.writeEntry("useCustomFontColor", m_useCustomFontColor);
+    if (m_useCustomFontColor) {
+        m_fontColor = ui.fontColor->color();
+    } else {
+        m_fontColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
+    }
+    cg.writeEntry("fontColor", ui.fontColor->color());
 
     m_fontTimeBold = ui.fontTimeBold->isChecked();
     cg.writeEntry("fontTimeBold", m_fontTimeBold);
 
+    m_fontTimeItalic = ui.fontTimeItalic->isChecked();
+    cg.writeEntry("fontTimeItalic", m_fontTimeItalic);
+
     m_fontTime.setBold(m_fontTimeBold);
+    m_fontTime.setItalic(m_fontTimeItalic);
 
     m_fuzzyness = ui.fuzzynessSlider->value();
     cg.writeEntry("fuzzyness", m_fuzzyness);
 
-    //save timezone even though we do not use it to allow the user to switch back easily.
-    QString unusedTimezone = m_timezone.name();
-
-    if ( ui.useLocalTimeZone->isChecked() ) { //use local timezone
-        dataEngine("time")->disconnectSource(m_timezone.name(), this);
-
-        m_timezone = m_localTimezone;
-        dataEngine("time")->connectSource(m_timezone.name(), this);
-    } else if ( !tzs.isEmpty() ) {
-        QString tz = tzs.at(0);
-
-        if ( tz != m_timezone.name() ) {//A different timezone was selected.
-            dataEngine("time")->disconnectSource(m_timezone.name(), this);
-            m_timezone = KSystemTimeZones::zone ( tz );
-            dataEngine("time")->connectSource(m_timezone.name(), this);
-        }
-    } else if ( m_timezone.name() != m_localTimezone.name() ) { //No timezone was selected and m_timezone is not the local timezone -> no time would show up.
-        dataEngine("time")->disconnectSource(m_timezone.name(), this);
-        m_timezone = m_localTimezone;
-        dataEngine("time")->connectSource(m_timezone.name(), this);
-    }
-
-    if ( ui.useLocalTimeZone->isChecked() ) { //save non-local timezone
-        cg.writeEntry("timezone", unusedTimezone);
-    } else {
-        cg.writeEntry("timezone", m_timezone.name());
-    }
-
-    m_useLocalTimezone = ui.useLocalTimeZone->isChecked();
-    cg.writeEntry("useLocalTimezone", m_useLocalTimezone);
-
     m_showDate = ui.showDate->isChecked();
     cg.writeEntry("showDate", m_showDate);
     m_showYear = ui.showYear->isChecked();
@@ -317,9 +258,7 @@ void Clock::configAccepted()
     m_showTimezone = ui.showTimezone->isChecked();
     cg.writeEntry("showTimezone", m_showTimezone);
 
-    kDebug() << "New timezone: " << m_timezone.name();
-
-    dataEngine("time")->connectSource(m_timezone.name(), this, 6000, Plasma::AlignToMinute);
+    dataEngine("time")->connectSource(currentTimezone(), this, 6000, Plasma::AlignToMinute);
 
     m_configUpdated = true;
     updateConstraints();
@@ -327,8 +266,10 @@ void Clock::configAccepted()
     emit configNeedsSaving();
 }
 
-Clock::~Clock()
+void Clock::changeEngineTimezone(const QString &oldTimezone, const QString &newTimezone)
 {
+    dataEngine("time")->disconnectSource(oldTimezone, this);
+    dataEngine("time")->connectSource(newTimezone, this, 6000, Plasma::AlignToMinute);
 }
 
 void Clock::calculateDateString()
@@ -373,22 +314,15 @@ void Clock::calculateDateString()
 //     }
 
     if( m_showTimezone == true ) {
-        m_timezoneString = '(' + m_timezone.name() + ')';
+        QString timezonetranslated = i18n( currentTimezone().toUtf8().data());
+        timezonetranslated = timezonetranslated.replace('_', ' ');
+        m_timezoneString = '(' + timezonetranslated  + ')';
     }
 }
 
-void Clock::calculateTimeString()
+void Clock::initFuzzyTimeStrings()
 {
-    if (!m_time.isValid()) {
-        return;
-    }
-
-    const int hours = m_time.hour();
-// int hours = 1;
-    const int minutes = m_time.minute();
-// int minutes = 0;
-
-    hourNames   << i18nc("hour in the messages below","one")
+    m_hourNames   << i18nc("hour in the messages below","one")
                 << i18nc("hour in the messages below","two")
                 << i18nc("hour in the messages below","three")
                 << i18nc("hour in the messages below","four")
@@ -401,8 +335,7 @@ void Clock::calculateTimeString()
                 << i18nc("hour in the messages below","eleven")
                 << i18nc("hour in the messages below","twelve");
 
-
-    normalFuzzy << ki18nc("%1 the hour translated above","%1 o'clock")
+    m_normalFuzzy << ki18nc("%1 the hour translated above","%1 o'clock")
                 << ki18nc("%1 the hour translated above","five past %1")
                 << ki18nc("%1 the hour translated above","ten past %1")
                 << ki18nc("%1 the hour translated above","quarter past %1")
@@ -416,16 +349,33 @@ void Clock::calculateTimeString()
                 << ki18nc("%1 the hour translated above","five to %1")
                 << ki18nc("%1 the hour translated above","%1 o'clock");
 
+    m_dayTime << i18n("Night")
+            << i18n("Early morning") << i18n("Morning") << i18n("Almost noon")
+            << i18n("Noon") << i18n("Afternoon") << i18n("Evening")
+            << i18n("Late evening");
+
+    m_weekTime << i18n("Start of week")
+               << i18n("Middle of week")
+               << i18n("End of week")
+               << i18n("Weekend!");
+}
+
+void Clock::calculateTimeString()
+{
+    if (!m_time.isValid()) {
+        return;
+    }
+
+    const int hours = m_time.hour();
+// int hours = 1;
+    const int minutes = m_time.minute();
+// int minutes = 0;
+
     bool upcaseFirst = i18nc("Whether to uppercase the first letter of "
                              "completed fuzzy time strings above: "
                              "translate as 1 if yes, 0 if no.",
                              "1") != QString('0');
 
-    dayTime << i18n("Night")
-            << i18n("Early morning") << i18n("Morning") << i18n("Almost noon")
-            << i18n("Noon") << i18n("Afternoon") << i18n("Evening")
-            << i18n("Late evening");
-
     //Create time-string
     QString newTimeString;
 
@@ -456,28 +406,31 @@ void Clock::calculateTimeString()
             realHour = 12 - ((hours + deltaHour) % 12 + 1);
         }
 
-        newTimeString = normalFuzzy[sector].subs(hourNames[realHour]).toString();
+        newTimeString = m_normalFuzzy[sector].subs(m_hourNames[realHour]).toString();
         if (upcaseFirst) {
             newTimeString.replace(0, 1, QString(newTimeString.at(0).toUpper()));
         }
     } else if (m_fuzzyness == 3) {
-        newTimeString = dayTime[hours / 3];
+        newTimeString = m_dayTime[hours / 3];
     } else {
         //Timezones not yet implemented: int dow = QDateTime::currentDateTime().addSecs(TZoffset).date().dayOfWeek();
         int dow = QDateTime::currentDateTime().date().dayOfWeek();
 
+        int weekStrIdx;
         if (dow == 1) {
-            newTimeString = i18n("Start of week");
+            weekStrIdx = 0;
         }
         else if (dow >= 2 && dow <= 4) {
-            newTimeString = i18n("Middle of week");
+            weekStrIdx = 1;
         }
         else if (dow == 5) {
-            newTimeString = i18n("End of week");
+            weekStrIdx = 2;
         }
         else {
-            newTimeString = i18n("Weekend!");
+            weekStrIdx = 3;
         }
+
+        newTimeString = m_weekTime[weekStrIdx];
     }
 
     m_timeString = newTimeString;
@@ -505,6 +458,15 @@ QFontMetrics m_fmDate ( m_fontDate );
 m_dateStringSize = QSizeF ( m_fmDate.width( m_dateString ), m_fmDate.height() );
 m_timezoneStringSize = QSizeF( m_fmDate.width( m_timezoneString ), m_fmDate.height() );
 
+int minimumWantedSize = KGlobalSettings::smallestReadableFont().pointSize();
+if (formFactor() == Plasma::Horizontal) {
+    QFont font(m_fontTime);
+    font.setPixelSize(size().height()/2);
+    QFontInfo fi(font);
+    minimumWantedSize = fi.pointSize();
+}
+
+
 if ( contentsRect().size().width() > m_timeStringSize.width() && (formFactor() == Plasma::Planar || formFactor() == Plasma::MediaCenter)) { //plasmoid wider than timestring
     kDebug() << "Plasmoid wider than the timestring";
     if( m_showDate == true && m_showTimezone == true ) { //date + timezone enabled
@@ -548,12 +510,14 @@ if ( contentsRect().size().width() > m_timeStringSize.width() && (formFactor() =
         kDebug() << "New minimumContentSize(): " << minimumSize();
     }
 
-    //Make the timestring fit the plasmoid since it is bigger than smallestReadable
-    m_fontTime.setPointSize(qMax((int)( geometry().size().height()/1.5), KGlobalSettings::smallestReadableFont().pointSize()) );
+    //Make the timestring fit the plasmoid since it is bigger than minimumWantedSize
+    m_fontTime.setPointSize(qMax((int)( geometry().size().height()/1.5), minimumWantedSize) );
 
     m_fmTime = QFontMetrics( m_fontTime );
 
-    while ( ( m_fmTime.width( m_timeString ) > contentsRect().size().width() - 2*m_margin || m_fmTime.height() > contentsRect().size().height() - m_subtitleStringSize.height() - m_verticalSpacing ) && m_fontTime.pointSize() > KGlobalSettings::smallestReadableFont().pointSize() ) {
+    while ( ( m_fmTime.width( m_timeString ) > contentsRect().size().width() - 2*m_margin ||
+              m_fmTime.height() > contentsRect().size().height() - m_subtitleStringSize.height() - m_verticalSpacing ) &&
+              m_fontTime.pointSize() > minimumWantedSize) {
 
         //decrease pointSize
         m_fontTime.setPointSize(m_fontTime.pointSize() - 1);
@@ -569,15 +533,16 @@ if ( contentsRect().size().width() > m_timeStringSize.width() && (formFactor() =
     if ( formFactor() == Plasma::Horizontal ) { //if we are on the panel we are forced to accept the given height.
         kDebug() << "needed height: " << m_contentSize.height() << "fixed height forced on us: " << geometry().size().height();
         //FIXME: it was resizing to size() itself
-        resize ( QSizeF ( m_contentSize.width(),geometry().size().height() ) );
+        //resize ( QSizeF ( m_contentSize.width(),geometry().size().height() ) );
     } else {
         //add margins
         resize ( m_contentSize + QSizeF(size()-contentsRect().size()) );
+        emit appletTransformedItself();
     }
 
 } else { //in a panel or timestring wider than plasmoid -> change size to the minimal needed space, i.e. the timestring will not increase in point-size OR plasmoid in Panel.
 
-    kDebug() << "Plasmoid is in a panel or too small for the timestring, we are using smallestReadable as pointSize";
+    kDebug() << "Plasmoid is in a panel or too small for the timestring, we are using minimumWantedSize as pointSize";
 
     if ( m_showDate == true && m_showTimezone == true ) { //Date + timezone enabled
         kDebug() << "Date + timezone enabled";
@@ -647,8 +612,8 @@ if ( contentsRect().size().width() > m_timeStringSize.width() && (formFactor() =
 
         //FIXME: if the clock is the only applet on a vertical panel and returns 0 via expandingDirections(), it still gets the full height of the panel as recommended height, i.e. on a vertical panel width a height of 800, geometry().size().height() does not return 48 but some huge value. Unless this is fixed in plasma, the while-loop will take a while.
 
-        //Make the timestring fit the plasmoid since it is bigger than smallestReadable
-        m_fontTime.setPointSize(qMax((int)( geometry().size().height()/1.5), KGlobalSettings::smallestReadableFont().pointSize()) );
+        //Make the timestring fit the plasmoid since it is bigger than minimumWantedSize
+        m_fontTime.setPointSize(qMax((int)( geometry().size().height()/1.5), minimumWantedSize) );
     
         m_fmTime = QFontMetrics( m_fontTime );
     
@@ -656,8 +621,9 @@ if ( contentsRect().size().width() > m_timeStringSize.width() && (formFactor() =
 
         kDebug() << "We want to have: \nwidth: < " << geometry().size().width() - 2*m_margin << "\nheight < " << (geometry().size().height() - m_subtitleStringSize.height() - m_verticalSpacing)*heightToUse;
 
-        //If we are in a horizontal panel, we ignore the width constraints, since we want to become as wide as it is needed in order to use the user-set height.
-        while ( ( ( m_fmTime.width( m_timeString ) > geometry().size().width() - 2*m_margin && formFactor() != Plasma::Horizontal ) || m_fmTime.height() > (geometry().size().height() - m_subtitleStringSize.height() - m_verticalSpacing)*heightToUse ) && m_fontTime.pointSize() > KGlobalSettings::smallestReadableFont().pointSize() ) {
+        while ( ( ( m_fmTime.width( m_timeString ) > geometry().size().width() - 2*m_margin && formFactor() != Plasma::Horizontal ) ||
+                 m_fmTime.height() > (geometry().size().height() - m_subtitleStringSize.height() - m_verticalSpacing)*heightToUse ) &&
+                 m_fontTime.pointSize() > minimumWantedSize) {
     
             //decrease pointSize
             m_fontTime.setPointSize(m_fontTime.pointSize() - 1);
@@ -675,36 +641,37 @@ if ( contentsRect().size().width() > m_timeStringSize.width() && (formFactor() =
 
     kDebug() << "Set new minimumSize: geometry().size() " << geometry().size() << "\nm_minimumContentSize: " << m_minimumContentSize;
 
-    //if the minimal width is larger than the actual size -> force minimal needed width
-    if( m_fontTime.pointSize() <= m_fontDate.pointSize() ) {
-            kDebug() << "Current minimal-width is too large for our needs. Since we are in a panel, we give that space back until we need it again.";
-            setMinimumSize ( m_minimumContentSize + (size() - contentsRect().size()) );
-        }
-
     //if the width given by the panel is too wide, e.g. when switching from panel at the right to panel at the bottom we get some 600 as width
     //However: If we are in a vertical panel, we should use the width given.
     if( m_timeStringSize.width() + m_margin*2 < geometry().size().width() && formFactor() != Plasma::Vertical ) {
             kDebug() << "The width we got was too big, we need less, so lets resize.";
-            resize ( m_minimumContentSize + (size() - contentsRect().size()) );
             setMinimumSize ( m_minimumContentSize + (size() - contentsRect().size()) );
         }
 
-    //Since panels only give us the space needed if we force them to do so, we have to set the minimum-size to whatever size we want. The user chose to use more width than with the default-font, so it should be ok.
     if ( formFactor() == Plasma::Horizontal ) { //if we are on the panel we are forced to accept the given height.
         kDebug() << "needed height: " << m_minimumContentSize.height() << "[horizontal panel] fixed height forced on us: " << geometry().size().height() << " adding margin-left/-right of: " << m_margin << "width is going to be set resize( " << m_minimumContentSize.width() << "," << geometry().size().height() << ")";
 
-        resize ( QSizeF ( m_minimumContentSize.width(),geometry().size().height() ) );
-        setMinimumSize ( QSizeF ( m_minimumContentSize.width(),geometry().size().height() ) );
+        setMinimumSize(QSizeF(m_minimumContentSize.width(), 0));
+        //Expand the panel as necessary
+        setPreferredSize(minimumSize());
+        emit sizeHintChanged(Qt::PreferredSize);
     } else if ( formFactor() == Plasma::Vertical ) {
         kDebug() << "needed width: " << m_minimumContentSize.width() << "[vertical panel] fixed width forced on us: " << geometry().size().width() << " adding margin left/right of: " << m_margin;
 
-        resize ( QSizeF ( geometry().size().width(),m_minimumContentSize.height() ) );
-        setMinimumSize ( QSizeF ( geometry().size().width(),m_minimumContentSize.height() ) );
+        setMinimumSize ( QSizeF(0, m_minimumContentSize.height()) );
+        //Expand the panel as necessary
+        setPreferredSize(minimumSize());
+        emit sizeHintChanged(Qt::PreferredSize);
     }else { //FIXME: In case this height does not fit the content -> disable timezone (and date)
+        //if the minimal width is larger than the actual size -> force minimal needed width
+        if( m_fontTime.pointSize() <= m_fontDate.pointSize() ) {
+            setMinimumSize ( m_minimumContentSize + (size() - contentsRect().size()) );
+        }
+
         //we use the minimal height here, since the user has given us too much height we cannot use for anything useful. minimal width because we are in a panel.
         kDebug() << "we set the minimum size needed as the size we want";
         resize ( QSizeF ( m_minimumContentSize.width() + m_margin*2,m_minimumContentSize.height() ) + (size() - contentsRect().size()) );
-        setMinimumSize ( QSizeF ( m_minimumContentSize.width() + m_margin*2,m_minimumContentSize.height() ) + (size() - contentsRect().size()) );
+        emit appletTransformedItself();
     }
 }
 }
@@ -754,4 +721,12 @@ void Clock::paintInterface(QPainter *p, const QStyleOptionGraphicsItem *option,
             );
 }
 
+void Clock::updateColors()
+{
+    if (!m_useCustomFontColor) {
+        m_fontColor = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme()).foreground().color();
+        update();
+    }
+}
+
 #include "fuzzyClock.moc"
