@@ -24,14 +24,27 @@
 #include <KRun>
 #include <KLocalizedString>
 #include <KDesktopFile>
+#include <KFileItem>
 #include <KIcon>
 #include <KGlobal>
 #include <KMimeType>
 #include <KUrl>
-#include <KDebug>
+#include <QApplication>
+#include <lancelot/models/PlasmaServiceListModel.h>
+
+#include "logger/Logger.h"
 
 namespace Models {
 
+class ApplicationConnector::Private {
+public:
+    Private()
+        : autohideEnabled(true)
+    {}
+
+    bool autohideEnabled;
+};
+
 ApplicationConnector * ApplicationConnector::m_instance = NULL;
 
 ApplicationConnector * ApplicationConnector::instance()
@@ -42,39 +55,70 @@ ApplicationConnector * ApplicationConnector::instance()
     return m_instance;
 }
 
+void ApplicationConnector::setAutohideEnabled(bool value)
+{
+    d->autohideEnabled = value;
+}
+
+bool ApplicationConnector::autohideEnabled() const
+{
+    return d->autohideEnabled;
+}
+
 void ApplicationConnector::search(const QString & search)
 {
     emit doSearch(search);
 }
 
-bool ApplicationConnector::hide(bool immediate)
+void ApplicationConnector::hide(bool immediate)
 {
-    return emit doHide(immediate);
+    if (d->autohideEnabled && !(QApplication::keyboardModifiers() & Qt::ControlModifier)) {
+        emit doHide(immediate);
+    }
 }
 
 ApplicationConnector::ApplicationConnector()
+    : d(new Private())
 {
 
 }
 
 ApplicationConnector::~ApplicationConnector()
 {
-
+    delete d;
 }
 
+class BaseModel::Private {
+public:
+    Private()
+        : enableDefaultDnD(false),
+          mimeData(NULL)
+    {
+    }
+
+    bool enableDefaultDnD;
+    QString title;
+    QIcon icon;
+    QMimeData * mimeData;
+};
 
 BaseModel::BaseModel(bool enableDefaultDnD)
-    : m_enableDefaultDnD(enableDefaultDnD)
+    : d(new Private())
 {
+    d->enableDefaultDnD = enableDefaultDnD;
 }
 
 BaseModel::~BaseModel()
 {
+    delete d;
 }
 
 void BaseModel::activate(int index)
 {
-    new KRun(KUrl(m_items.at(index).data.toString()), 0);
+    QString data = itemAt(index).data.toString();
+
+    Logger::instance()->log("base-model", data);
+    new KRun(KUrl(data), 0);
     hideLancelotWindow();
 }
 
@@ -92,7 +136,7 @@ int BaseModel::addServices(const QStringList & serviceNames)
 {
     int result = 0;
     foreach (const QString & serviceAlternatives, serviceNames) {
-        foreach (const QString & serviceName, serviceAlternatives.split("|")) {
+        foreach (const QString & serviceName, serviceAlternatives.split('|')) {
             if (addService(serviceName)) {
                 ++result;
                 break;
@@ -145,6 +189,8 @@ bool BaseModel::addUrl(const QString & url)
 
 bool BaseModel::addUrl(const KUrl & url)
 {
+    KFileItem fileItem(KFileItem::Unknown, KFileItem::Unknown, url);
+
     if (url.isLocalFile() && QFileInfo(url.path()).suffix() == "desktop") {
         // .desktop files may be services (type field == 'Application' or 'Service')
         // or they may be other types such as links.
@@ -170,9 +216,9 @@ bool BaseModel::addUrl(const KUrl & url)
         );
     } else {
         add(
-            QFileInfo(url.path()).baseName(),
+            fileItem.text(),
             url.isLocalFile() ? url.path() : url.prettyUrl(),
-            KIcon(KMimeType::iconNameForUrl(url)),
+            KIcon(fileItem.iconName()),
             url.url()
         );
     }
@@ -183,7 +229,6 @@ bool BaseModel::addUrl(const KUrl & url)
 QMimeData * BaseModel::mimeForUrl(const KUrl & url)
 {
     QMimeData * data = new QMimeData();
-    kDebug() << url.url();
     data->setData("text/uri-list", url.url().toAscii());
     data->setData("text/plain", url.url().toAscii());
     return data;
@@ -191,19 +236,17 @@ QMimeData * BaseModel::mimeForUrl(const KUrl & url)
 
 QMimeData * BaseModel::mimeData(int index) const
 {
-    if (!m_enableDefaultDnD) {
-        kDebug() << "Requested mime for index" << index
-            << "but we don't support DnD";
+    if (!d->enableDefaultDnD) {
         return NULL;
     }
 
-    kDebug() << "Requested mime for index" << index;
-    return BaseModel::mimeForUrl(m_items.at(index).data.toString());
+    return BaseModel::mimeForUrl(itemAt(index).data.toString());
 }
 
 void BaseModel::setDropActions(int index,
             Qt::DropActions & actions, Qt::DropAction & defaultAction)
 {
+    Q_UNUSED(index);
     actions = Qt::CopyAction;
     defaultAction = Qt::CopyAction;
 }
@@ -227,4 +270,35 @@ QMimeData * BaseModel::mimeForService(const QString & serviceName)
     return mimeForService(service);
 }
 
+
+QString BaseModel::selfTitle() const
+{
+    return d->title;
+}
+
+QIcon BaseModel::selfIcon() const
+{
+    return d->icon;
+}
+
+QMimeData * BaseModel::selfMimeData() const
+{
+    return d->mimeData;
+}
+
+void BaseModel::setSelfTitle(const QString & title)
+{
+    d->title = title;
+}
+
+void BaseModel::setSelfIcon(const QIcon & icon)
+{
+    d->icon = icon;
+}
+
+void BaseModel::setSelfMimeData(QMimeData * data)
+{
+    d->mimeData = data;
+}
+
 } // namespace Models
