@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOTAPP_MODELS_FOLDERMODEL_H_
-#define LANCELOTAPP_MODELS_FOLDERMODEL_H_
+#ifndef LANCELOTAPP_MODELS_FOLDERMODEL_H
+#define LANCELOTAPP_MODELS_FOLDERMODEL_H
 
 #include "BaseModel.h"
 #include <QDir>
@@ -30,18 +30,18 @@ namespace Models {
 class FolderModel : public BaseModel {
     Q_OBJECT
 public:
-    FolderModel(QString dirPath, QDir::SortFlags sort = QDir::NoSort);
+    explicit FolderModel(QString dirPath, QDir::SortFlags sort = QDir::NoSort);
     virtual ~FolderModel();
 
 protected:
     void load();
 
-private:
+protected:
     KDirLister * m_dirLister;
     QString m_dirPath;
     QDir::SortFlags m_sort;
 
-private Q_SLOTS:
+protected Q_SLOTS:
     void clear();
     void deleteItem(const KFileItem & fileItem);
     void newItems(const KFileItemList & items);
@@ -49,4 +49,4 @@ private Q_SLOTS:
 
 } // namespace Models
 
-#endif /* LANCELOTAPP_MODELS_FOLDERMODEL_H_ */
+#endif /* LANCELOTAPP_MODELS_FOLDERMODEL_H */
