@@ -1,41 +1,39 @@
 /*
  *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
- *   Copyright (C) 2007 Robert Knight <robertknight@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Lesser/Library General Public License version 2,
+ *   it under the terms of the GNU General Public License version 2,
  *   or (at your option) any later version, as published by the Free
  *   Software Foundation
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Lesser/Library General Public License for more details
+ *   GNU General Public License for more details
  *
- *   You should have received a copy of the GNU Lesser/Library General Public
+ *   You should have received a copy of the GNU General Public
  *   License along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOTAPP_MODELS_NEWDOCUMENTS_H_
-#define LANCELOTAPP_MODELS_NEWDOCUMENTS_H_
+#ifndef LANCELOTAPP_MODELS_NEWDOCUMENTS_H
+#define LANCELOTAPP_MODELS_NEWDOCUMENTS_H
 
-#include "BaseModel.h"
+#include "FolderModel.h"
 
 namespace Models {
 
-class NewDocuments : public BaseModel {
+class NewDocuments : public FolderModel {
     Q_OBJECT
 public:
     NewDocuments();
     virtual ~NewDocuments();
 
-protected:
-    void load();
+    static QString path();
 
 };
 
 } // namespace Models
 
-#endif /* LANCELOTAPP_MODELS_NEWDOCUMENTS_H_ */
+#endif /* LANCELOTAPP_MODELS_NEWDOCUMENTS_H */
