@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOTAPP_MODELS_RECENTDOCUMENTS_H_
-#define LANCELOTAPP_MODELS_RECENTDOCUMENTS_H_
+#ifndef LANCELOTAPP_MODELS_RECENTDOCUMENTS_H
+#define LANCELOTAPP_MODELS_RECENTDOCUMENTS_H
 
 #include "FolderModel.h"
 #include <KDirWatch>
@@ -30,8 +30,12 @@ class RecentDocuments : public FolderModel {
 public:
     RecentDocuments();
     virtual ~RecentDocuments();
+
+    L_Override bool hasContextActions(int index) const;
+    L_Override void setContextActions(int index, Lancelot::PopupMenu * menu);
+    L_Override void contextActivate(int index, QAction * context);
 };
 
 } // namespace Models
 
-#endif /* LANCELOTAPP_MODELS_RECENTDOCUMENTS_H_ */
+#endif /* LANCELOTAPP_MODELS_RECENTDOCUMENTS_H */
