@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LIBLANCELOT_H_
-#define LIBLANCELOT_H_
+#ifndef LIBLANCELOT_H
+#define LIBLANCELOT_H
 
 #include <QWidget>
 #include <QMetaObject>
@@ -58,14 +58,14 @@ enum ActivationMethod {
         virtual const QMetaObject * L_metaObject() const { \
             return L_INITD_META_OBJECT;                    \
         }                                                  \
-    public:                                                \
-        virtual void L_debug() const {                     \
-            kDebug() << " 0 "                              \
-               << "This" << (void *)this                   \
-               << "Stati" << (void *)L_INITD_META_OBJECT   \
-               << "QMeta" << (void *)metaObject()          \
-               << "LMeta" << (void *)L_metaObject();       \
-        }
+//    public:
+//        virtual void L_debug() const {
+//            kDebug() << " 0 "
+//               << "This" << (void *)this
+//               << "Stati" << (void *)L_INITD_META_OBJECT
+//               << "QMeta" << (void *)metaObject()
+//               << "LMeta" << (void *)L_metaObject();
+//        }
 //        virtual void L_debugFull() const {
 //            kDebug() << " 1 " << L_metaObject()->className();
 //            kDebug() << " 2 " << metaObject()->className();
@@ -74,11 +74,11 @@ enum ActivationMethod {
 //        }
 
 #define L_WIDGET_IS_INITIALIZED  L_isInitialized()
-#define L_WIDGET_SET_INITIALIZED L_setInitialized(); groupUpdated(); updateGeometry(); \
-    kDebug() << "initialized" << (void*)this << "of class" << metaObject()->className();
+#define L_WIDGET_SET_INITIALIZED L_setInitialized(); groupUpdated(); updateGeometry();
+//    kDebug() << "initialized" << (void*)this << "of class" << metaObject()->className();
 #define L_WIDGET_UNSET_INITIALIZED  L_isInitialized()
 
 } // namespace Lancelot
 
-#endif // LIBLANCELOT_H_
+#endif // LIBLANCELOT_H
 
